import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useEffect, useState } from 'react';
import { createRoot } from 'react-dom/client';
import Jupyter from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Output } from '../components/output/Output';
const CODE = `from time import sleep
for i in range(0, 7):
      sleep(i)
      print("👉 " + str(i))

print("✨ Done!")
`;
const KernelExecutorView = () => {
    const { defaultKernel } = useJupyter();
    const [outputAreaModel, setOutputAreaModel] = useState();
    const [done, setDone] = useState(false);
    useEffect(() => {
        if (defaultKernel?.connection) {
            const kernelExecutor = defaultKernel.execute(CODE);
            kernelExecutor?.outputAreaModelChanged.connect((_, outputAreaModel) => {
                setOutputAreaModel(outputAreaModel);
            });
            kernelExecutor?.executed.then(() => {
                setDone(true);
            });
        }
    }, [defaultKernel?.connection]);
    return (_jsxs(_Fragment, { children: [outputAreaModel &&
                _jsx(_Fragment, { children: _jsx(Output, { outputAreaModel: outputAreaModel }) }), done &&
                _jsx(_Fragment, { children: "\u2728\u2728 Done!" })] }));
};
const KernelExecutor = () => {
    return (_jsx(Jupyter, { children: _jsx(KernelExecutorView, {}) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(KernelExecutor, {}));
//# sourceMappingURL=KernelExecutor.js.map