/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { Signal } from '@lumino/signaling';
import { OutputAreaModel } from '@jupyterlab/outputarea';
export class KernelExecutor {
    _kernelConnection;
    _outputs;
    _outputsChanged = new Signal(this);
    _outputAreaModel;
    _outputAreaModelChanged = new Signal(this);
    _executeReplyReceived = new Signal(this);
    _future;
    _executed;
    _executedResolve;
    constructor(kernelConnection) {
        this._kernelConnection = kernelConnection;
        this._outputs = [];
        this._outputAreaModel = new OutputAreaModel();
        this._executed = new Promise((resolve, _) => {
            this._executedResolve = resolve;
        });
    }
    execute(code) {
        const future = this._kernelConnection.requestExecute({
            code,
        });
        this.future = future;
        return future;
    }
    _onIOPub = (message) => {
        const messageType = message.header.msg_type;
        const output = { ...message.content, output_type: messageType };
        switch (messageType) {
            case 'execute_result':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._outputAreaModel.add(output);
                this._outputAreaModelChanged.emit(this._outputAreaModel);
                break;
            case 'stream':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._outputAreaModel.add(output);
                this._outputAreaModelChanged.emit(this._outputAreaModel);
                break;
            case 'display_data':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._outputAreaModel.add(output);
                this._outputAreaModelChanged.emit(this._outputAreaModel);
                break;
            case 'update_display_data':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._outputAreaModel.add(output);
                this._outputAreaModelChanged.emit(this._outputAreaModel);
                break;
            default:
                break;
        }
    };
    _onReply = (message) => {
        const messageType = message.header.msg_type;
        switch (messageType) {
            case 'execute_reply':
                const output = {
                    output_type: 'display_data',
                    data: message.content.data,
                    metadata: {}
                };
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._outputAreaModel.add(output);
                this.executeReplyReceived.emit(this._outputAreaModel);
                this._executedResolve();
                break;
            default:
                break;
        }
    };
    get executed() {
        return this._executed;
    }
    get future() {
        return this._future;
    }
    set future(value) {
        this._future = value;
        if (!value) {
            return;
        }
        value.onIOPub = this._onIOPub;
        value.onReply = this._onReply;
    }
    get outputs() {
        return this._outputs;
    }
    get outputsChanged() {
        return this._outputsChanged;
    }
    get outputAreaModel() {
        return this._outputAreaModel;
    }
    get outputAreaModelChanged() {
        return this._outputAreaModelChanged;
    }
    get executeReplyReceived() {
        return this._executeReplyReceived;
    }
}
export default KernelExecutor;
//# sourceMappingURL=KernelExecutor.js.map